@@ -4,7 +4,7 @@
  * See the main source file 'vdr.c' for copyright information and
  * how to reach the author.
  *
- * $Id: dvbdevice.h 2.14 2010/04/11 10:29:37 kls Exp $
+ * $Id: dvbdevice.h 2.15 2011/06/02 13:20:05 kls Exp $
  */
 
 #ifndef __DVBDEVICE_H
@@ -127,22 +127,6 @@ public:
   virtual ~cDvbDevice();
   virtual bool Ready(void);
 
-#ifdef USE_LNBSHARE
-private:
-  char lnbState;  // Current frequency band and polarization of the DVB-tuner
-  //  cDiseqc *lnbSource;  // can not #include "diseqc.h". A workaround follows:
-  int *lnbSource;  // [DiSEqC] DiSEqC-Source
-  int lnbNr;      // Number of LNB used
-public:
-  int *LnbSource(void) { return lnbSource; };
-  virtual int LnbNr(void) const { if(ProvidesSource(cSource::stSat)) return lnbNr; return CardIndex() * -1;};
-  virtual void SetLnbNrFromSetup(void);
-
-public:
-  virtual bool IsLnbConflict(const cChannel *Channel);
-  virtual bool IsShareLnb(const cDevice *Device);
-#endif /* LNBSHARE */
-
 // Common Interface facilities:
 
 private:
@@ -157,15 +141,14 @@ public:
   virtual bool ProvidesTransponder(const cChannel *Channel) const;
   virtual bool ProvidesChannel(const cChannel *Channel, int Priority = -1, bool *NeedsDetachReceivers = NULL) const;
   virtual int NumProvidedSystems(void) const;
+  virtual int SignalStrength(void) const;
+  virtual int SignalQuality(void) const;
   virtual const cChannel *GetCurrentlyTunedTransponder(void) const;
   virtual bool IsTunedToTransponder(const cChannel *Channel);
 protected:
   virtual bool SetChannelDevice(const cChannel *Channel, bool LiveView);
 public:
   virtual bool HasLock(int TimeoutMs = 0);
-#ifdef USE_ROTOR
-  virtual bool SendDiseqcCmd(dvb_diseqc_master_cmd cmd);
-#endif /* ROTOR */
 
 // PID handle facilities
 
@@ -215,6 +198,7 @@ class cDvbDeviceProbe : public cListObject {
 public:
   cDvbDeviceProbe(void);
   virtual ~cDvbDeviceProbe();
+  static uint32_t GetSubsystemId(int Adapter, int Frontend);
   virtual bool Probe(int Adapter, int Frontend) = 0;
      ///< Probes for a DVB device at the given Adapter and creates the appropriate
      ///< object derived from cDvbDevice if applicable.
