@@ -6,7 +6,7 @@
  *
  * Original author: Marco Schller <marco@lordzodiac.de>
  *
- * $Id: dvbsubtitle.h 2.3 2010/05/13 14:43:44 kls Exp $
+ * $Id: dvbsubtitle.h 2.6 2011/03/20 13:34:23 kls Exp $
  */
 
 #ifndef __DVBSUBTITLE_H
@@ -29,11 +29,18 @@ private:
   int ddsVersionNumber;
   int displayWidth;
   int displayHeight;
-  int displayHorizontalOffset;
-  int displayVerticalOffset;
+  int windowHorizontalOffset;
+  int windowVerticalOffset;
+  int windowWidth;
+  int windowHeight;
+  int osdDeltaX;
+  int osdDeltaY;
+  double osdFactorX;
+  double osdFactorY;
   cList<cDvbSubtitlePage> *pages;
   cList<cDvbSubtitleBitmaps> *bitmaps;
   tColor yuv2rgb(int Y, int Cb, int Cr);
+  void SetOsdData(void);
   bool AssertOsd(void);
   int ExtractSegment(const uchar *Data, int Length, int64_t Pts);
   void FinishPage(cDvbSubtitlePage *Page);
