@@ -18,9 +18,6 @@
 #include "menuitems.h"
 #include "recorder.h"
 #include "skins.h"
-#ifdef USE_SETUP
-#include "submenu.h"
-#endif /* SETUP */
 
 class cMenuText : public cOsdMenu {
 private:
@@ -54,9 +51,6 @@ public:
   cMenuFolder(const char *Title, cNestedItemList *NestedItemList, const char *Path = NULL);
   cString GetFolder(void);
   virtual eOSState ProcessKey(eKeys Key);
-#ifdef USE_GRAPHTFT
-  virtual const char* MenuKind() { return "MenuText"; }
-#endif /* GRAPHTFT */
   };
 
 class cMenuCommands : public cOsdMenu {
@@ -90,9 +84,6 @@ public:
   cMenuEditTimer(cTimer *Timer, bool New = false);
   virtual ~cMenuEditTimer();
   virtual eOSState ProcessKey(eKeys Key);
-#ifdef USE_GRAPHTFT
-  virtual const char* MenuKind() { return "MenuTimerEdit"; }
-#endif /* GRAPHTFT */
   };
 
 class cMenuEvent : public cOsdMenu {
@@ -102,37 +93,22 @@ public:
   cMenuEvent(const cEvent *Event, bool CanSwitch = false, bool Buttons = false);
   virtual void Display(void);
   virtual eOSState ProcessKey(eKeys Key);
-#ifdef USE_GRAPHTFT
-  virtual const char* MenuKind() { return "MenuEvent"; }
-#endif /* GRAPHTFT */
   };
 
 class cMenuMain : public cOsdMenu {
 private:
-#ifdef USE_SETUP
-  int    nrDynamicMenuEntries;
-#endif /* SETUP */
   bool replaying;
   cOsdItem *stopReplayItem;
   cOsdItem *cancelEditingItem;
   cOsdItem *stopRecordingItem;
   int recordControlsState;
   static cOsdObject *pluginOsdObject;
-#ifdef USE_SETUP
-  void Set(int current=0);
-  bool Update(bool Force = false);
-  cSubMenu subMenu;
-#else
   void Set(void);
   bool Update(bool Force = false);
-#endif /* SETUP */
 public:
   cMenuMain(eOSState State = osUnknown);
   virtual eOSState ProcessKey(eKeys Key);
   static cOsdObject *PluginOsdObject(void);
-#ifdef USE_GRAPHTFT
-  virtual const char* MenuKind() { return "MenuMain"; }
-#endif /* GRAPHTFT */
   };
 
 class cDisplayChannel : public cOsdObject {
@@ -228,9 +204,6 @@ private:
   eOSState Delete(void);
   eOSState Info(void);
   eOSState Commands(eKeys Key = kNone);
-#ifdef USE_LIEMIEXT
-  eOSState Rename(void);
-#endif /* LIEMIEXT */
 protected:
   cRecording *GetRecording(cMenuRecordingItem *Item);
 public:
@@ -249,11 +222,7 @@ private:
   char *fileName;
   bool GetEvent(void);
 public:
-#ifdef USE_ALTERNATECHANNEL
-  cRecordControl(cDevice *Device, cTimer *Timer = NULL, bool Pause = false, cChannel *Channel = NULL);
-#else
   cRecordControl(cDevice *Device, cTimer *Timer = NULL, bool Pause = false);
-#endif /* ALTERNATECHANNEL */
   virtual ~cRecordControl();
   bool Process(time_t t);
   cDevice *Device(void) { return device; }
@@ -270,9 +239,6 @@ private:
 public:
   static bool Start(cTimer *Timer = NULL, bool Pause = false);
   static void Stop(const char *InstantId);
-#ifdef USE_LNBSHARE
-  static void Stop(cDevice *Device);   // LNB Sharing
-#endif /* LNBSHARE */
   static bool PauseLiveVideo(void);
   static const char *GetInstantId(const char *LastInstantId);
   static cRecordControl *GetRecordControl(const char *FileName);
@@ -287,20 +253,11 @@ public:
 class cReplayControl : public cDvbPlayerControl {
 private:
   cSkinDisplayReplay *displayReplay;
-#ifdef USE_JUMPPLAY
-  cMarksReload marks;
-#else
   cMarks marks;
-#endif /* JUMPPLAY */
   bool visible, modeOnly, shown, displayFrames;
   int lastCurrent, lastTotal;
   bool lastPlay, lastForward;
   int lastSpeed;
-#ifdef USE_LIEMIEXT
-  int lastSkipSeconds;
-  eKeys lastSkipKey;
-  cTimeMs lastSkipTimeout;
-#endif /* LIEMIEXT */
   time_t timeoutShow;
   bool timeSearchActive, timeSearchHide;
   int timeSearchTime, timeSearchPos;
