@@ -4,7 +4,7 @@
  * See the main source file 'vdr.c' for copyright information and
  * how to reach the author.
  *
- * $Id: menuitems.c 2.7 2010/06/06 10:37:08 kls Exp $
+ * $Id: menuitems.c 2.10 2011/08/12 13:19:40 kls Exp $
  */
 
 #include "menuitems.h"
@@ -33,21 +33,9 @@ cMenuEditItem::~cMenuEditItem()
   free(name);
 }
 
-#ifdef USE_VALIDINPUT
-void cMenuEditItem::SetValue(const char *Value, bool HasPre, bool HasSucc)
-#else
 void cMenuEditItem::SetValue(const char *Value)
-#endif /* VALIDINPUT */
 {
   cString buffer = cString::sprintf("%s:\t%s", name, Value);
-#ifdef USE_VALIDINPUT
-  if (Setup.ShowValidInput) {
-     if (HasPre && HasSucc) buffer = cString::sprintf("%s:\t<%s>", name, Value);
-     else if (HasPre)       buffer = cString::sprintf("%s:\t<%s",  name, Value);
-     else if (HasSucc)      buffer = cString::sprintf("%s:\t%s>",  name, Value);
-     }
-#endif /* VALIDINPUT */
-
   SetText(buffer);
   cStatus::MsgOsdCurrentItem(buffer);
 }
@@ -139,11 +127,7 @@ void cMenuEditBoolItem::Set(void)
 {
   char buf[16];
   snprintf(buf, sizeof(buf), "%s", *value ? trueString : falseString);
-#ifdef USE_VALIDINPUT
-  SetValue(buf, *value, !*value);
-#else
   SetValue(buf);
-#endif /* VALIDINPUT */
 }
 
 // --- cMenuEditBitItem ------------------------------------------------------
@@ -543,7 +527,7 @@ eOSState cMenuEditStrItem::ProcessKey(eKeys Key)
      Set();
      return osContinue;
      }
-  switch (Key) {
+  switch (int(Key)) {
     case kRed:   // Switch between upper- and lowercase characters
                  if (InEditMode()) {
                     if (!insert || !newchar) {
@@ -721,11 +705,7 @@ cMenuEditStraItem::cMenuEditStraItem(const char *Name, int *Value, int NumString
 
 void cMenuEditStraItem::Set(void)
 {
-#ifdef USE_VALIDINPUT
-  SetValue(strings[*value], (*value > min), (*value < max));
-#else
   SetValue(strings[*value]);
-#endif /* VALIDINPUT */
 }
 
 // --- cMenuEditChanItem -----------------------------------------------------
@@ -733,7 +713,19 @@ void cMenuEditStraItem::Set(void)
 cMenuEditChanItem::cMenuEditChanItem(const char *Name, int *Value, const char *NoneString)
 :cMenuEditIntItem(Name, Value, NoneString ? 0 : 1, Channels.MaxNumber())
 {
+  channelID = NULL;
   noneString = NoneString;
+  dummyValue = 0;
+  Set();
+}
+
+cMenuEditChanItem::cMenuEditChanItem(const char *Name, cString *ChannelID, const char *NoneString)
+:cMenuEditIntItem(Name, &dummyValue, NoneString ? 0 : 1, Channels.MaxNumber())
+{
+  channelID = ChannelID;
+  noneString = NoneString;
+  cChannel *channel = Channels.GetByChannelID(tChannelID::FromString(*ChannelID));
+  dummyValue = channel ? channel->Number() : 0;
   Set();
 }
 
@@ -744,16 +736,21 @@ void cMenuEditChanItem::Set(void)
      cChannel *channel = Channels.GetByNumber(*value);
      snprintf(buf, sizeof(buf), "%d %s", *value, channel ? channel->Name() : "");
      SetValue(buf);
+     if (channelID)
+        *channelID = channel->GetChannelID().ToString();
      }
-  else if (noneString)
+  else if (noneString) {
      SetValue(noneString);
+     if (channelID)
+        *channelID = "";
+     }
 }
 
 eOSState cMenuEditChanItem::ProcessKey(eKeys Key)
 {
   int delta = 1;
 
-  switch (Key) {
+  switch (int(Key)) {
     case kLeft|k_Repeat:
     case kLeft:  delta = -1;
     case kRight|k_Repeat:
@@ -764,6 +761,8 @@ eOSState cMenuEditChanItem::ProcessKey(eKeys Key)
                       *value = channel->Number();
                    else if (delta < 0 && noneString)
                       *value = 0;
+                   if (channelID)
+                      *channelID = channel ? channel->GetChannelID().ToString() : "";
                    Set();
                  }
                  break;
