@@ -317,14 +317,6 @@ void cPluginManager::AddPlugin(const char *Args)
   char *p = strchr(s, ' ');
   if (p)
      *p = 0;
-#ifdef USE_PLUGINMISSING
-  struct stat st;
-  if (stat (cString::sprintf("%s/%s%s%s%s", directory, LIBVDR_PREFIX, s, SO_INDICATOR, APIVERSION), &st) && errno == ENOENT) {
-     esyslog("WARN: missing plugin '%s'", s);
-     fprintf(stderr, "vdr: missing plugin '%s'\n", s);
-     }
-  else
-#endif /* PLUGINMISSING */
   dlls.Add(new cDll(cString::sprintf("%s/%s%s%s%s", directory, LIBVDR_PREFIX, s, SO_INDICATOR, APIVERSION), Args));
   free(s);
 }
@@ -333,11 +325,7 @@ bool cPluginManager::LoadPlugins(bool Log)
 {
   for (cDll *dll = dlls.First(); dll; dll = dlls.Next(dll)) {
       if (!dll->Load(Log))
-#ifdef USE_PLUGINMISSING
-         ;
-#else
          return false;
-#endif /* PLUGINMISSING */
       }
   return true;
 }
