@@ -4,7 +4,7 @@
  * See the main source file 'vdr.c' for copyright information and
  * how to reach the author.
  *
- * $Id: remux.c 2.53 2011/03/20 10:21:14 kls Exp $
+ * $Id: remux.c 2.58 2011/08/15 09:50:14 kls Exp $
  */
 
 #include "remux.h"
@@ -12,6 +12,7 @@
 #include "libsi/si.h"
 #include "libsi/section.h"
 #include "libsi/descriptor.h"
+#include "recording.h"
 #include "shutdown.h"
 #include "tools.h"
 
@@ -134,8 +135,11 @@ void TsSetTeiOnBrokenPackets(uchar *p, int l)
         if (!Processed[Pid]) {
            if (!TsPayloadStart(p))
               p[1] |= TS_ERROR;
-           else
+           else {
               Processed[Pid] = true;
+              int offs = TsPayloadOffset(p);
+              cRemux::SetBrokenLink(p + offs, TS_SIZE - offs);
+              }
            }
         l -= TS_SIZE;
         p += TS_SIZE;
@@ -781,7 +785,8 @@ cFrameDetector::cFrameDetector(int Pid, int Type)
 {
   SetPid(Pid, Type);
   synced = false;
-  newFrame = independentFrame = false;
+  newPayload = newFrame = independentFrame = false;
+  frameTypeOffset = -1;
   numPtsValues = 0;
   numFrames = 0;
   numIFrames = 0;
@@ -808,7 +813,8 @@ void cFrameDetector::SetPid(int Pid, int Type)
 
 void cFrameDetector::Reset(void)
 {
-  newFrame = independentFrame = false;
+  newPayload = newFrame = independentFrame = false;
+  frameTypeOffset = -1;
   payloadUnitOfFrame = 0;
   scanning = false;
   scanner = EMPTY_SCANNER;
@@ -816,9 +822,8 @@ void cFrameDetector::Reset(void)
 
 int cFrameDetector::Analyze(const uchar *Data, int Length)
 {
-  int SeenPayloadStart = false;
   int Processed = 0;
-  newFrame = independentFrame = false;
+  newPayload = newFrame = independentFrame = false;
   while (Length >= TS_SIZE) {
         if (Data[0] != TS_SYNC_BYTE) {
            int Skipped = 1;
@@ -831,16 +836,13 @@ int cFrameDetector::Analyze(const uchar *Data, int Length)
            int Pid = TsPid(Data);
            if (Pid == pid) {
               if (TsPayloadStart(Data)) {
-                 SeenPayloadStart = true;
                  if (synced && Processed)
-                    return Processed;
-                 if (Length < MIN_TS_PACKETS_FOR_FRAME_DETECTOR * TS_SIZE)
-                    return Processed; // need more data, in case the frame type is not stored in the first TS packet
+                    return Processed; // flush everything before this new payload
                  if (framesPerSecond <= 0.0) {
                     // frame rate unknown, so collect a sequence of PTS values:
                     if (numPtsValues < MaxPtsValues && numIFrames < 2) { // collect a sequence containing at least two I-frames
                        const uchar *Pes = Data + TsPayloadOffset(Data);
-                       if (PesHasPts(Pes)) {
+                       if (numIFrames && PesHasPts(Pes)) {
                           ptsValues[numPtsValues] = PesGetPts(Pes);
                           // check for rollover:
                           if (numPtsValues && ptsValues[numPtsValues - 1] > 0xF0000000 && ptsValues[numPtsValues] < 0x10000000) {
@@ -885,8 +887,8 @@ int cFrameDetector::Analyze(const uchar *Data, int Length)
                              else
                                 framesPerSecond = 60.0 / 1.001;
                           else {
-                             framesPerSecond = 25.0;
-                             dsyslog("unknown frame delta (%d), assuming 25 fps", Delta);
+                             framesPerSecond = DEFAULTFRAMESPERSECOND;
+                             dsyslog("unknown frame delta (%d), assuming %5.2f fps", Delta, DEFAULTFRAMESPERSECOND);
                              }
                           }
                        else // audio
@@ -900,6 +902,10 @@ int cFrameDetector::Analyze(const uchar *Data, int Length)
               if (scanning) {
                  int PayloadOffset = TsPayloadOffset(Data);
                  if (TsPayloadStart(Data)) {
+                    if (synced && Processed)
+                       return Processed; // flush everything before this new payload
+                    newPayload = true;
+                    scanner = EMPTY_SCANNER;
                     PayloadOffset += PesPayloadOffset(Data + PayloadOffset);
                     if (!framesPerPayloadUnit)
                        framesPerPayloadUnit = framesInPayloadUnit;
@@ -907,17 +913,30 @@ int cFrameDetector::Analyze(const uchar *Data, int Length)
                        dbgframes("/");
                     }
                  for (int i = PayloadOffset; scanning && i < TS_SIZE; i++) {
-                     scanner <<= 8;
-                     scanner |= Data[i];
+                     if (frameTypeOffset < 0) {
+                        scanner <<= 8;
+                        scanner |= Data[i];
+                        }
+                     else
+                        frameTypeOffset += PayloadOffset;
                      switch (type) {
                        case 0x01: // MPEG 1 video
                        case 0x02: // MPEG 2 video
                             if (scanner == 0x00000100) { // Picture Start Code
+                               if (frameTypeOffset < 0) {
+                                  frameTypeOffset = i + 2;
+                                  if (frameTypeOffset >= TS_SIZE) { // the byte to check is in the next TS packet
+                                     frameTypeOffset -= TS_SIZE;
+                                     if (!synced)
+                                        dbgframes("%d>", frameTypeOffset);
+                                     break;
+                                     }
+                                  }
                                scanner = EMPTY_SCANNER;
-                               if (synced && !SeenPayloadStart && Processed)
-                                  return Processed; // flush everything before this new frame
                                newFrame = true;
-                               independentFrame = ((Data[i + 2] >> 3) & 0x07) == 1; // I-Frame
+                               uchar FrameType = (Data[frameTypeOffset] >> 3) & 0x07;
+                               frameTypeOffset = -1;
+                               independentFrame = FrameType == 1; // I-Frame
                                if (synced) {
                                   if (framesPerPayloadUnit <= 1)
                                      scanning = false;
@@ -928,7 +947,7 @@ int cFrameDetector::Analyze(const uchar *Data, int Length)
                                      numIFrames++;
                                   if (numIFrames == 1)
                                      numFrames++;
-                                  dbgframes("%d ", (Data[i + 2] >> 3) & 0x07);
+                                  dbgframes("%u ", FrameType);
                                   }
                                if (synced)
                                   return Processed + TS_SIZE; // flag this new frame
@@ -936,11 +955,20 @@ int cFrameDetector::Analyze(const uchar *Data, int Length)
                             break;
                        case 0x1B: // MPEG 4 video
                             if (scanner == 0x00000109) { // Access Unit Delimiter
+                               if (frameTypeOffset < 0) {
+                                  frameTypeOffset = i + 1;
+                                  if (frameTypeOffset >= TS_SIZE) { // the byte to check is in the next TS packet
+                                     frameTypeOffset -= TS_SIZE;
+                                     if (!synced)
+                                        dbgframes("%d>", frameTypeOffset);
+                                     break;
+                                     }
+                                  }
                                scanner = EMPTY_SCANNER;
-                               if (synced && !SeenPayloadStart && Processed)
-                                  return Processed; // flush everything before this new frame
                                newFrame = true;
-                               independentFrame = Data[i + 1] == 0x10;
+                               uchar FrameType = Data[frameTypeOffset];
+                               frameTypeOffset = -1;
+                               independentFrame = FrameType == 0x10;
                                if (synced) {
                                   if (framesPerPayloadUnit < 0) {
                                      payloadUnitOfFrame = (payloadUnitOfFrame + 1) % -framesPerPayloadUnit;
@@ -958,7 +986,7 @@ int cFrameDetector::Analyze(const uchar *Data, int Length)
                                      numIFrames++;
                                   if (numIFrames == 1)
                                      numFrames++;
-                                  dbgframes("%02X ", Data[i + 1]);
+                                  dbgframes("%02X ", FrameType);
                                   }
                                if (synced)
                                   return Processed + TS_SIZE; // flag this new frame
