@@ -79,9 +79,6 @@ private:
   void CmdPLUG(const char *Option);
   void CmdPUTE(const char *Option);
   void CmdREMO(const char *Option);
-#ifdef USE_LIEMIEXT
-  void CmdRENR(const char *Option);
-#endif /* LIEMIEXT */
   void CmdSCAN(const char *Option);
   void CmdSTAT(const char *Option);
   void CmdUPDT(const char *Option);
